@@ -8,7 +8,10 @@ Check these declarations against the C/Fortran source code.
 /* .C calls */
 extern void loopC(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void loopU(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void mstepU(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+//extern void mstepU(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void mstepU (int *NN, int *pp, int *GG, double *z,
+            double *sigmar, double *invsigmar, double *mu, double *mmtol,
+            int *mmmax, double *x, char **covtype, double *PXgood);
 extern void RdCN(void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void RestepC(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void RestepU(void *, void *, void *, void *, void *, void *, void *, void *);
